@@ -74,8 +74,11 @@ def _search_lines(
     for lineno, line in enumerate(lines):
         match = regex_compiled.search(line)
         if match:
-            group = match.groupdict()
-            comments.append(_CodeTag(lineno + 1, tag=group['tag'], text=group['text']))
+            if len(line) <= 400:  # FYI: Suppress long lines
+                group = match.groupdict()
+                comments.append(_CodeTag(lineno + 1, tag=group['tag'], text=group['text']))
+            else:
+                logger.debug('Skipping long line {lineno}: `{line}`', lineno=lineno, line=line[:200])
     return comments
 
 
@@ -149,8 +152,11 @@ def _format_record(base_dir: Path, file_path: Path, comment: _CodeTag) -> Dict[s
     blame = None
     try:
         blame = run_cmd(f'git blame {file_path} -L {comment.lineno},{comment.lineno} --porcelain', cwd=cwd)
-    except CalledProcessError:
-        logger.exception('Failed to locate {file_path}', file_path=file_path)
+    except CalledProcessError as exc:
+        if exc.returncode != 128:
+            raise
+        logger.debug('Skipping blame of: {exc}', file_path=file_path, exc=exc)
+
     # Set fallback values if git logic doesn't work
     rel_path = file_path.relative_to(base_dir)
     source_file = f'{rel_path.as_posix()}:{comment.lineno}'
@@ -210,7 +216,7 @@ def _format_report(
                 counter[comment.tag] += 1
     if records:
         df_tags = pd.DataFrame(records)
-        output += df_tags.to_markdown(index=False)
+        output += df_tags.to_markdown(index=False, tablefmt='github')
     logger.debug('counter={counter}', counter=counter)
 
     sorted_counter = {tag: counter[tag] for tag in tag_order if tag in counter}
